@@ -1,10 +1,14 @@
+import copy
+from abc import ABC
+
 import numpy as np
 import pygame
+from dataclasses import dataclass
 
 from pysnakegym.game.core.direction import Direction
 from pysnakegym.game.core.point import Point
 from pysnakegym.game import colour
-from pysnakegym.game.core.grid import Grid
+from pysnakegym.game.core.grid import Grid, SnakeGameSequence, GameSequence
 
 
 class SnakeGame(object):
@@ -206,6 +210,13 @@ class SnakeGame(object):
         """
         return self.grid.grid.copy()
 
+    def get_sequence(self) -> GameSequence:
+        """
+        Gets a sequence of the game which can be used to replay the game.
+        :return: A GameSequence object containing the Snake and Food.
+        """
+        return SnakeGameSequence(copy.deepcopy(self.grid.snake()), copy.deepcopy(self.grid.food()))
+
 
 class PyGameSnakeGame(SnakeGame):
     """
@@ -264,3 +275,39 @@ class PyGameSnakeGame(SnakeGame):
         label = score_font.render(str(self.score()), 1, (255, 255, 255))
         self.window.blit(label, (1, 1))
         pygame.display.flip()
+
+
+class GameSequencePlayer(ABC):
+    sequences = []
+
+    def add(self, sequence: GameSequence):
+        pass
+
+    def play(self):
+        pass
+
+    def reset(self):
+        self.sequences = []
+
+
+@dataclass
+class SnakeGameSequencePlayer(GameSequencePlayer):
+    delay: int
+    record: bool
+    record_path: str
+
+    def add(self, sequence: SnakeGameSequence):
+        self.sequences.append(sequence)
+
+    def play(self):
+        game = PyGameSnakeGame(screen_width=800, screen_height=800, snake_size=80)
+        game.start()
+        for sequence in self.sequences:
+            game.grid._snake = sequence.snake
+            game.grid._food = sequence.food
+            game.draw_snake()
+            game.draw_food()
+            game.display_score()
+            game.clock.tick(self.delay)
+            if self.record:
+                pygame.image.save(game.window, f'{self.record_path}/game_{self.sequences.index(sequence)}.jpg')
