@@ -35,6 +35,7 @@ class GridState(SnakeState):
         self.game = game
 
     def get_state(self) -> np.array:
+
         grid = self.game.grid.grid.copy()
         np.place(grid, grid == -1, 0)
 
@@ -45,9 +46,11 @@ class GridState(SnakeState):
         for segment in snake_body[1:]:
             x = int(segment[0])
             y = int(segment[1])
-            grid[y][x] = 191
+            if not self.is_outside(x) and not self.is_outside(y):
+                grid[y][x] = 191
 
-        grid[snake_head_y][snake_head_x] = 255
+        if not self.is_outside(snake_head_x) and not self.is_outside(snake_head_y):
+            grid[snake_head_y][snake_head_x] = 255
         grid[food_y][food_x] = 127
 
         return grid
@@ -55,6 +58,8 @@ class GridState(SnakeState):
     def dims(self) -> (int, int):
         return 10, 10
 
+    def is_outside(self, n):
+        return n < 0 or n > 9
 
 class BooleanState(SnakeState):
     """
@@ -70,6 +75,7 @@ class BooleanState(SnakeState):
         self.previous_head = Point(game.snake_head().x, game.snake_head().y + 1)
 
     def get_state(self) -> np.array:
+
         snake_head = self.game.snake_head()
         snake_body = self.game.snake_position()[1:, :]
 
